import { createContext, useState, useEffect, useCallback } from 'react';
import { io } from 'socket.io-client';

export const SocketContext = createContext();

export const SocketProvider = ({ children }) => {
  const [socket, setSocket] = useState(null);
  const [connected, setConnected] = useState(false);

  const connect = useCallback(() => {
    if (!socket) {
      const newSocket = io(window.location.hostname === 'localhost' ? 'http://localhost:5287' : '/');
      
      newSocket.on('connect', () => {
        setConnected(true);
        console.log('Socket connected');
      });
      
      newSocket.on('disconnect', () => {
        setConnected(false);
        console.log('Socket disconnected');
      });

      setSocket(newSocket);
    }
  }, [socket]);

  const disconnect = useCallback(() => {
    if (socket) {
      socket.disconnect();
      setSocket(null);
      setConnected(false);
    }
  }, [socket]);

  const send = useCallback((event, data) => {
    if (socket) {
      socket.emit(event, data);
    } else {
      console.error('Cannot send event, socket not connected');
    }
  }, [socket]);

  const on = useCallback((event, callback) => {
    if (socket) {
      socket.on(event, callback);
    }
    return () => {
      if (socket) socket.off(event, callback);
    };
  }, [socket]);

  useEffect(() => {
    return () => {
      if (socket) socket.disconnect();
    };
  }, [socket]);

  return (
    <SocketContext.Provider value={{ connected, connect, disconnect, send, on, socket }}>
      {children}
    </SocketContext.Provider>
  );
};
